@@ -1,4 +1,4 @@
-(* $Id: morph3d.ml,v 1.10 2001/09/06 08:47:55 garrigue Exp $ *)
+(* $Id: morph3d.ml,v 1.10.4.1 2003/04/14 06:24:30 garrigue Exp $ *)
 
 open StdLabels
 
@@ -490,7 +490,7 @@ class view area = object (self)
     | "4" -> obj <- 4
     | "5" -> obj <- 5
     | "\r" -> smooth <- not smooth
-    | "\027" -> Gaux.may area#misc#toplevel ~f:(fun w -> w#destroy ()); exit 0
+    | "\027" -> area#misc#toplevel#destroy (); exit 0
     | _ -> ()
     end;
     self#pinit
