@@ -1,4 +1,4 @@
-(* $Id: gWindow.ml,v 1.21 2001/03/12 03:43:42 garrigue Exp $ *)
+(* $Id: gWindow.ml,v 1.23 2003/01/10 07:47:12 garrigue Exp $ *)
 
 open Gaux
 open Gtk
@@ -46,6 +46,12 @@ let window ?kind:(t=`TOPLEVEL) ?title ?wm_name ?wm_class ?position
   if show then Widget.show w;
   new window w
 
+let cast_window (w : #widget) =
+  new window (GtkWindow.Window.cast w#as_widget)
+
+let toplevel (w : #widget) =
+  try Some (cast_window w#misc#toplevel) with Cannot_cast _ -> None
+
 class dialog obj = object
   inherit [window] window_skel (obj : Gtk.dialog obj)
   method connect = new container_signals obj
@@ -98,6 +104,8 @@ class file_selection obj = object
   method cancel_button =
     new GButton.button (FileSelection.get_cancel_button obj)
   method help_button = new GButton.button (FileSelection.get_help_button obj)
+  method file_list =
+    ((new GList.clist (FileSelection.get_file_list obj)) : string GList.clist)
 end
 
 let file_selection ?(title="Choose a file") ?filename
