@@ -1,4 +1,4 @@
-(* $Id: gWindow.mli,v 1.20 2001/03/12 03:43:43 garrigue Exp $ *)
+(* $Id: gWindow.mli,v 1.23.2.1 2003/06/11 09:09:01 garrigue Exp $ *)
 
 open Gtk
 open GObj
@@ -7,10 +7,10 @@ class ['a] window_skel : 'b obj ->
   object
     inherit GContainer.container
     constraint 'a = 'a #window_skel
-    constraint 'b = [>`widget|`container|`bin|`window]
+    constraint 'b = [> window]
     val obj : 'b obj
-    method activate_default : unit -> unit
-    method activate_focus : unit -> unit
+    method activate_default : unit -> bool
+    method activate_focus : unit -> bool
     method add_accel_group : accel_group -> unit
     method event : event_ops
     method as_window : Gtk.window obj
@@ -49,6 +49,9 @@ val window :
   ?border_width:int ->
   ?width:int -> ?height:int -> ?show:bool -> unit -> window
 
+val toplevel : #widget -> window option
+(** return the toplevel window of this widget, if existing *)
+
 class dialog : Gtk.dialog obj ->
   object
     inherit [window] window_skel
@@ -106,6 +109,7 @@ class file_selection : Gtk.file_selection obj ->
     method get_filename : string
     method help_button : GButton.button
     method ok_button : GButton.button
+    method file_list : string GList.clist
     method set_filename : string -> unit
     method set_fileop_buttons : bool -> unit
   end
