@@ -1,4 +1,4 @@
-(* $Id: gtkEdit.ml,v 1.14 2001/09/06 08:47:56 garrigue Exp $ *)
+(* $Id: gtkEdit.ml,v 1.15.2.3 2003/05/21 14:51:57 furuse Exp $ *)
 
 open StdLabels
 open Gaux
@@ -43,10 +43,10 @@ module Editable = struct
   module Signals = struct
     open GtkArgv
     open GtkSignal
-    let activate : ([>`editable],_) t =
-      { name = "activate"; marshaller = marshal_unit }
-    let changed : ([>`editable],_) t =
-      { name = "changed"; marshaller = marshal_unit }
+    let activate =
+      { name = "activate"; classe = `editable; marshaller = marshal_unit }
+    let changed =
+      { name = "changed"; classe = `editable; marshaller = marshal_unit }
     let marshal_insert f argv = function
       | STRING _ :: INT len :: POINTER(Some pos) :: _ ->
           (* XXX These two accesses are implementation-dependent *)
@@ -54,16 +54,45 @@ module Editable = struct
           and pos = int_at_pointer pos in
           f s ~pos
       | _ -> invalid_arg "GtkEdit.Editable.Signals.marshal_insert"
-    let insert_text : ([>`editable],_) t =
-      { name = "insert_text"; marshaller = marshal_insert }
+    let insert_text =
+      { name = "insert_text"; classe = `editable; marshaller = marshal_insert }
     let marshal_delete f _ = function
       | INT start :: INT stop :: _ ->
           f ~start ~stop
       | _ -> invalid_arg "GtkEdit.Editable.Signals.marshal_delete"
-    let delete_text : ([>`editable],_) t =
-      { name = "delete_text"; marshaller = marshal_delete }
+    let delete_text =
+      { name = "delete_text"; classe = `editable; marshaller = marshal_delete }
+    let copy_clipboard =
+      { name = "copy_clipboard"; classe = `editable; 
+	marshaller = marshal_unit }
+    let cut_clipboard =
+      { name = "copy_clipboard"; classe = `editable; 
+	marshaller = marshal_unit }
+    let paste_clipboard =
+      { name = "copy_clipboard"; classe = `editable; 
+	marshaller = marshal_unit }
+    let move_cursor =
+      { name = "move_cursor"; classe = `editable; 
+	marshaller = marshal_int2 }
+    let move_word =
+      { name = "move_word"; classe = `editable; 
+	marshaller = marshal_int }
+    let move_page =
+      { name = "move_page"; classe = `editable; 
+	marshaller = marshal_int }
+    let move_to_row =
+      { name = "move_to_row"; classe = `editable; 
+	marshaller = marshal_int }
+    let move_to_column =
+      { name = "move_to_column"; classe = `editable; 
+	marshaller = marshal_int }
   end
-end
+  let emit_move_cursor = GtkSignal.emit_int2 ~sgn:Signals.move_cursor
+  let emit_move_word = GtkSignal.emit_int ~sgn:Signals.move_word
+  let emit_move_page = GtkSignal.emit_int ~sgn:Signals.move_page
+  let emit_move_to_row = GtkSignal.emit_int ~sgn:Signals.move_to_row
+  let emit_move_to_column = GtkSignal.emit_int ~sgn:Signals.move_to_column
+ end
 
 module Entry = struct
   let cast w : entry obj = Object.try_cast w "GtkEntry"
@@ -112,7 +141,7 @@ module SpinButton = struct
       = "ml_gtk_spin_button_set_digits"
   external get_value : [>`spinbutton] obj -> float
       = "ml_gtk_spin_button_get_value_as_float"
-  let get_value_as_int w = truncate (get_value w +. 0.5)
+  let get_value_as_int w = truncate (floor (get_value w +. 0.5))
   external set_value : [>`spinbutton] obj -> float -> unit
       = "ml_gtk_spin_button_set_value"
   external set_update_policy :
@@ -175,6 +204,10 @@ module Text = struct
     if hadjustment <> None || vadjustment <> None then
       set_adjustment w ?horizontal: hadjustment ?vertical: vadjustment ();
     may word_wrap ~f:(set_word_wrap w)
+  external forward_delete: [>`text] obj -> int -> unit = 
+    "ml_gtk_text_forward_delete"
+  external backward_delete: [>`text] obj -> int -> unit = 
+    "ml_gtk_text_backward_delete"
 end
 
 module Combo = struct
