@@ -1,4 +1,4 @@
-(* $Id: gtkWindow.ml,v 1.12 2001/03/12 03:43:43 garrigue Exp $ *)
+(* $Id: gtkWindow.ml,v 1.15.2.1 2003/06/11 09:08:33 garrigue Exp $ *)
 
 open Gaux
 open Gtk
@@ -11,7 +11,7 @@ module Window = struct
   external set_title : [>`window] obj -> string -> unit
       = "ml_gtk_window_set_title"
   external set_wmclass : [>`window] obj -> name:string -> clas:string -> unit
-      = "ml_gtk_window_set_title"
+      = "ml_gtk_window_set_wmclass"
   external get_wmclass_name : [>`window] obj -> string
       = "ml_gtk_window_get_wmclass_name"
   external get_wmclass_class : [>`window] obj -> string
@@ -68,16 +68,13 @@ module Window = struct
   external remove_accel_group :
       [>`window] obj -> accel_group -> unit
       = "ml_gtk_window_remove_accel_group"
-  external activate_focus : [>`window] obj -> unit
-      = "ml_gtk_window_activate_focus"
-  external activate_default : [>`window] obj -> unit
-      = "ml_gtk_window_activate_default"
   module Signals = struct
     open GtkSignal
-    let move_resize : ([>`window],_) t =
-      { name = "move_resize"; marshaller = marshal_unit }
-    let set_focus : ([>`window],_) t =
-      { name = "set_focus"; marshaller = Widget.Signals.marshal_opt }
+    let move_resize =
+      { name = "move_resize"; classe = `window; marshaller = marshal_unit }
+    let set_focus =
+      { name = "set_focus"; classe = `window;
+        marshaller = Widget.Signals.marshal_opt }
   end
 end
 
@@ -95,10 +92,12 @@ module InputDialog = struct
   external create : unit -> input_dialog obj = "ml_gtk_input_dialog_new"
   module Signals = struct
     open GtkSignal
-    let enable_device : ([>`inputdialog],_) t =
-      { name = "enable_device"; marshaller = marshal_int }
-    let disable_device : ([>`inputdialog],_) t =
-      { name = "disable_device"; marshaller = marshal_int }
+    let enable_device =
+      { name = "enable_device"; classe = `inputdialog;
+        marshaller = marshal_int }
+    let disable_device =
+      { name = "disable_device"; classe = `inputdialog;
+        marshaller = marshal_int }
   end
 end
 
@@ -121,6 +120,8 @@ module FileSelection = struct
       = "ml_gtk_file_selection_get_cancel_button"
   external get_help_button : [>`filesel] obj -> button obj
       = "ml_gtk_file_selection_get_help_button"
+  external get_file_list : [>`filesel] obj -> clist obj
+      = "ml_gtk_file_selection_get_file_list"
   let set_fileop_buttons w = function
       true -> show_fileop_buttons w
     | false -> hide_fileop_buttons w
