@@ -1,4 +1,4 @@
-/* $Id: ml_gtk.c,v 1.107 2002/07/16 07:54:06 garrigue Exp $ */
+/* $Id: ml_gtk.c,v 1.108.2.1 2003/05/13 07:52:43 garrigue Exp $ */
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -514,6 +514,8 @@ Make_Extractor (gtk_file_selection_get, GtkFileSelection_val, cancel_button,
 		Val_GtkWidget)
 Make_Extractor (gtk_file_selection_get, GtkFileSelection_val, help_button,
 		Val_GtkWidget)
+Make_Extractor (gtk_file_selection_get, GtkFileSelection_val, file_list,
+		Val_GtkWidget)
 
 /* gtkwindow.h */
 
@@ -868,6 +870,8 @@ ML_2_name (ml_gtk_signal_emit_none, gtk_signal_emit_by_name,
            GtkObject_val, String_val, Unit)
 ML_3_name (ml_gtk_signal_emit_int, gtk_signal_emit_by_name,
            GtkObject_val, String_val, Int_val, Unit)
+ML_4_name (ml_gtk_signal_emit_int2, gtk_signal_emit_by_name,
+           GtkObject_val, String_val, Int_val, Int_val, Unit)
 ML_4_name (ml_gtk_signal_emit_scroll, gtk_signal_emit_by_name,
            GtkObject_val, String_val, Scroll_type_val, Double_val, Unit)
 
