@@ -1,4 +1,4 @@
-/* $Id: ml_gtklist.c,v 1.3 2002/07/15 03:43:29 garrigue Exp $ */
+/* $Id: ml_gtklist.c,v 1.4.2.1 2003/05/15 14:21:19 furuse Exp $ */
 
 #include <string.h>
 #include <gtk/gtk.h>
@@ -166,3 +166,29 @@ ML_2 (gtk_clist_set_sort_column, GtkCList_val, Int_val, Unit)
 ML_2 (gtk_clist_set_sort_type, GtkCList_val, Sort_type_val, Unit)
 ML_1 (gtk_clist_sort, GtkCList_val, Unit)
 ML_2 (gtk_clist_set_auto_sort, GtkCList_val, Bool_val, Unit)
+
+CAMLprim value ml_gtk_clist_get_row_state (value clist, value y)
+{
+    GtkCListRow *row;
+    GList *list;
+    gint row_num;
+
+    list = GtkCList_val(clist)->row_list;
+
+    for (row_num=0; row_num < Int_val(y) ; row_num++) {
+      if (list == NULL) invalid_argument ("Gtk.Clist.get_row_state");
+      list = list->next;
+    }
+
+    row = list->data;
+    return (Val_state_type (row->state));
+}
+
+static value val_int(gpointer i)
+{
+  return Val_int (GPOINTER_TO_INT(i));
+}
+CAMLprim value ml_gtk_clist_selection (value clist)
+{
+  return( Val_GList(GtkCList_val(clist)->selection, val_int) );
+}
