@@ -1,4 +1,4 @@
-/* $Id: wrappers.c,v 1.16 2000/11/16 08:15:22 garrigue Exp $ */
+/* $Id: wrappers.c,v 1.17 2002/10/31 03:27:38 garrigue Exp $ */
 
 #include <string.h>
 #include <caml/mlvalues.h>
@@ -6,6 +6,7 @@
 #include <caml/memory.h>
 #include <caml/callback.h>
 #include <caml/fail.h>
+#include <glib.h>
 
 #include "wrappers.h"
 
@@ -54,6 +55,13 @@ value copy_string_or_null (const char*str)
     return copy_string (str ? (char*) str : "");
 }
 
+value copy_string_g_free (char *str)
+{
+    value ret = copy_string (str);
+    g_free (str);
+    return ret;
+}
+
 value *ml_global_root_new (value v)
 {
     value *p = stat_alloc(sizeof(value));
